@@ -1,17 +1,18 @@
-# $Id: TLPOBJ.pm 46422 2018-01-24 04:13:22Z preining $
+# $Id: TLPOBJ.pm 48521 2018-08-31 03:41:21Z preining $
 # TeXLive::TLPOBJ.pm - module for using tlpobj files
-# Copyright 2007-2017 Norbert Preining
+# Copyright 2007-2018 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
 
 package TeXLive::TLPOBJ;
 
-my $svnrev = '$Revision: 46422 $';
+my $svnrev = '$Revision: 48521 $';
 my $_modulerevision = ($svnrev =~ m/: ([0-9]+) /) ? $1 : "unknown";
 sub module_revision { return $_modulerevision; }
 
 use TeXLive::TLConfig qw($DefaultCategory $CategoriesRegexp 
                          $MetaCategoriesRegexp $InfraLocation 
+                         %Compressors $DefaultCompressorFormat
                          $RelocPrefix $RelocTree);
 use TeXLive::TLCrypto;
 use TeXLive::TLTREE;
@@ -558,9 +559,13 @@ sub common_texmf_tree {
 
 sub make_container {
   my ($self,$type,$instroot,$destdir,$containername,$relative) = @_;
-  if (($type ne "xz") && ($type ne "tar")) {
-    die "$0: TLPOBJ supports tar and xz containers, not $type";
+  if (!($type eq 'tar' ||
+        TeXLive::TLUtils::member($type, @{$::progs{'working_compressors'}}))) {
+    tlwarn "$0: TLPOBJ supports @{$::progs{'working_compressors'}} and tar containers, not $type\n";
+    tlwarn "$0: falling back to $DefaultCompressorFormat as container type!\n";
+    $type = $DefaultCompressorFormat;
   }
+
   if (!defined($containername)) {
     $containername = $self->name;
   }
@@ -622,27 +627,16 @@ sub make_container {
   close(TMP);
   push(@files, "$tlpobjdir/$self->{'name'}.tlpobj");
   $tarname = "$containername.tar";
-  if ($type eq "tar") {
-    $containername = $tarname;
-  } else {
-    $containername = "$tarname.xz";
-  }
 
   # start the fun
   my $tar = $::progs{'tar'};
-  my $xz;
   if (!defined($tar)) {
     tlwarn("$0: programs not set up, trying \"tar\".\n");
     $tar = "tar";
   }
-  if ($type eq "xz") {
-    $xz = $::progs{'xz'};
-    if (!defined($xz)) {
-      tlwarn("$0: programs not set up, trying \"xz\".\n");
-      $xz = "xz";
-    }
-  }
-  
+
+  $containername = $tarname;
+
   # Here we need to distinguish between making the master containers for
   # tlnet (where we can assume GNU tar) and making backups on a user's
   # machine (where we can assume nothing).  We determine this by whether
@@ -720,12 +714,29 @@ sub make_container {
   unlink("$destdir/$containername");
   xsystem(@cmdline);
 
-  # compress it.
-  if ($type eq "xz") {
+  if ($type ne 'tar') {
+    # compress it
+    my $compressor = $::progs{$type};
+    if (!defined($compressor)) {
+      # fall back to $type as compressor, but that shouldn't happen
+      tlwarn("$0: programs not set up, trying \"$type\".\n");
+      $compressor = $type;
+    }
+    my @compressorargs = @{$Compressors{$type}{'compress_args'}};
+    my $compressorextension = $Compressors{$type}{'extension'};
+    $containername = "$tarname.$compressorextension";
+    debug("selected compressor: $compressor with @compressorargs, "
+          . "on $destdir/$tarname\n");
+  
+    # compress it.
     if (-r "$destdir/$tarname") {
-      system($xz, "--force", "-z", "$destdir/$tarname");
+      # system return 0 on success
+      if (system($compressor, @compressorargs, "$destdir/$tarname")) {
+        tlwarn("$0: Couldn't compress $destdir/$tarname\n");
+        return (0,0, "");
+      }
     } else {
-      tlwarn("$0: Couldn't find $destdir/$tarname to run $xz\n");
+      tlwarn("$0: Couldn't find $destdir/$tarname to run $compressor\n");
       return (0, 0, "");
     }
   }
@@ -811,7 +822,7 @@ sub update_from_catalogue {
       $foo =~ s/^.Date: //;
       # trying to extract the interesting part of a subversion date
       # keyword expansion here, e.g.,
-      # $Date: 2018-01-24 05:13:22 +0100 (Wed, 24 Jan 2018) $
+      # $Date: 2018-08-31 05:41:21 +0200 (Fri, 31 Aug 2018) $
       # ->2007-08-15 19:43:35 +0100
       $foo =~ s/ \(.*\)( *\$ *)$//;  # maybe nothing after parens
       $self->cataloguedata->{'date'} = $foo;
@@ -833,9 +844,17 @@ sub update_from_catalogue {
     if (@{$entry->also}) {
       $self->cataloguedata->{'also'} = "@{$entry->also}";
     }
+    if (@{$entry->alias}) {
+      $self->cataloguedata->{'alias'} = "@{$entry->alias}";
+    }
     if (@{$entry->topics}) {
       $self->cataloguedata->{'topics'} = "@{$entry->topics}";
     }
+    if (%{$entry->contact}) {
+      for my $k (keys %{$entry->contact}) {
+        $self->cataloguedata->{"contact-$k"} = $entry->contact->{$k};
+      }
+    }
     #if (defined($entry->texlive)) {
     # $self->cataloguedata->{'texlive'} = $entry->texlive;
     #}
