@@ -1,6 +1,6 @@
-# $Id: TLWinGoo.pm 40600 2016-04-18 21:56:02Z karl $
-# TeXLive::TLWinGoo.pm - Windows nastiness
-# Copyright 2008-2016 Siep Kroonenberg, Norbert Preining
+# $Id: TLWinGoo.pm 47907 2018-06-03 18:09:29Z karl $
+# TeXLive::TLWinGoo.pm - Windows goop.
+# Copyright 2008-2018 Siep Kroonenberg, Norbert Preining
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
 
@@ -11,16 +11,14 @@
 
 package TeXLive::TLWinGoo;
 
-my $svnrev = '$Revision: 40600 $';
+my $svnrev = '$Revision: 47907 $';
 my $_modulerevision;
 if ($svnrev =~ m/: ([0-9]+) /) {
   $_modulerevision = $1;
 } else {
   $_modulerevision = "unknown";
 }
-sub module_revision {
-  return $_modulerevision;
-}
+sub module_revision { return $_modulerevision; }
 
 =pod
 
@@ -34,8 +32,9 @@ C<TeXLive::TLWinGoo> -- Additional utilities for Windows
 
 =head2 DIAGNOSTICS
 
-  TeXLive::TLWinGoo::win_version;
   TeXLive::TLWinGoo::is_vista;
+  TeXLive::TLWinGoo::is_seven;
+  TeXLive::TLWinGoo::is_ten;
   TeXLive::TLWinGoo::admin;
   TeXLive::TLWinGoo::non_admin;
   TeXLive::TLWinGoo::reg_country;
@@ -93,11 +92,12 @@ BEGIN {
   @ISA = qw( Exporter );
   @EXPORT = qw(
     &is_vista
+    &is_seven
+    &is_ten
     &admin
     &non_admin
   );
   @EXPORT_OK = qw(
-    &win_version
     &admin_again
     &reg_country
     &broadcast_env
@@ -175,7 +175,7 @@ if ($is_win) {
   $SendMessage = new Win32::API('user32', 'SendMessageTimeout', 'LLPPLLP', 'L');
   debug ("Import failure SendMessage\n") unless $SendMessage;
   $update_fu = new Win32::API('shell32', 'SHChangeNotify', 'LIPP', 'V');
-  debug ("Import failure assoc_notify\n") unless $assoc_fu;
+  debug ("Import failure assoc_notify\n") unless $update_fu;
 }
 
 =pod
@@ -194,23 +194,48 @@ registry: 5.0 for Windows 2000, 5.1 for Windows XP and 6.0 for Vista.
 =cut
 
 my $windows_version = 0;
+my $windows_subversion = 0;
 
 if ($is_win) {
-  my @osver = Win32::GetOSVersion();
-  $windows_version = $osver[1];
-  debug "Windows version $osver[0], major version $osver[1]\n";
+  #my @osver = Win32::GetOSVersion(); # deprecated
+  #$windows_version = $osver[1];
+  #debug "Windows version $osver[0], major version $osver[1]\n";
+  my $ver = `ver`;
+  chomp $ver;
+  $ver =~ s/^[^0-9]*//;
+  $ver =~ s/[^0-9.]*$//;
+  ($windows_version = $ver) =~ s/\..*$//;
+  ($windows_subversion = $ver) =~ s/^[^\.]*\.//;
+  $windows_subversion =~ s/\..*$//;
 }
 
-sub win_version { return $windows_version; }
-
 =item C<is_vista>
 
-C<is_vista> returns 1 if win_version is >= 6.0, otherwise 0.
+C<is_vista> returns 1 if windows version is >= 6.0, otherwise 0.
 
 =cut
 
 sub is_vista { return $windows_version >= 6; }
 
+=item C<is_seven>
+
+C<is_seven> returns 1 if windows version is >= 6.1, otherwise 0.
+
+=cut
+
+sub is_seven {
+  return (($windows_version == 6 && $windows_subversion >= 1) ||
+    ($windows_version > 6));
+}
+
+=item C<is_ten>
+
+C<is_ten> returns 1 if windows version is >= 10.0, otherwise 0.
+
+=cut
+
+sub is_ten { return $windows_version >= 10; }
+
 # permissions with which we try to access the system environment
 
 my $is_admin = 1;
@@ -771,20 +796,50 @@ sub do_remove_regkey {
   return 1;
 }
 
+#############################
+# not overwriting an existing file association
+
+# read error is sometimes access_denied,
+# therefore we ONLY decide that a value does not exist if
+# an attempt to read it errors out with file_not_found.
+
+# windows error codes
+my $file_not_found = 2; # ERROR_FILE_NOT_FOUND
+my $reg_ok = 0; # ERROR_SUCCESS
+
+# inaccessible value (note. actual filetypes shound not have spaces)
+my $reg_unknown = 'not accessible';
+
 # Effective default value of any key under Classes.
 # admin: HKLM; user: HKCU or otherwise HKLM
-# Reject if there is no corresponding key under classes
 sub current_filetype {
   my $extension = shift;
   my $filetype;
+  my $regerror;
+
   if ($is_admin) {
-    $filetype = lm_root()->{"Software/Classes/$extension//"}; # REG_SZ
+    $regerror = $reg_ok;
+    $filetype = lm_root()->{"Software/Classes/$extension//"} # REG_SZ
+      or $regerror = Win32API::Registry::regLastError();
+    if ($regerror != $reg_ok and $regerror != $file_not_found) {
+      return $reg_unknown;
+    }
   } else {
     # Mysterious failures on w7_64 => merge HKLM/HKCU info explicitly
     # rather than checking HKCR
-    $filetype = cu_root()->{"Software/Classes/$extension//"};
+    $regerror = $reg_ok;
+    $filetype = cu_root()->{"Software/Classes/$extension//"} or
+      $regerror = Win32API::Registry::regLastError();
+    if ($regerror != $reg_ok and $regerror != $file_not_found) {
+      return $reg_unknown;
+    }
     if (!defined($filetype) or ($filetype eq "")) {
-      $filetype = lm_root()->{"Software/Classes/$extension//"}
+      $regerror = $reg_ok;
+      $filetype = lm_root()->{"Software/Classes/$extension//"} or
+        $regerror = Win32API::Registry::regLastError();
+      if ($regerror != $reg_ok and $regerror != $file_not_found) {
+        return $reg_unknown;
+      }
     };
   }
   $filetype = "" unless defined($filetype);
@@ -856,7 +911,7 @@ sub register_extension {
   my $regkey;
 
   my $old_file_type = current_filetype($extension);
-  if ($old_file_type) {
+  if ($old_file_type and $old_file_type ne $reg_unknown) {
     if ($is_admin) {
       if (not lm_root()->{"Software/Classes/$old_file_type/"}) {
         $old_file_type = "";
@@ -870,16 +925,20 @@ sub register_extension {
   }
   # admin: whether to remove HKCU entry. admin never _writes_ to HKCU
   my $remove_cu = ($mode == 2) && admin();
+
   # can do the following safely:
   debug ("Adding $file_type to OpenWithProgIds of $extension\n");
   add_to_progids ($extension, $file_type);
+
   if ($old_file_type and $old_file_type ne $file_type) {
     if ($mode == 1) {
       debug ("Not overwriting $old_file_type with $file_type for $extension\n");
-    } else {
+    } else { # $mode ==2, overwrite
       debug("Linking $extension to $file_type\n");
-      debug ("Moving $old_file_type to OpenWithProgIds\n");
-      add_to_progids ($extension, $old_file_type);
+      if ($old_file_type ne $reg_unknown) {
+        debug ("Moving $old_file_type to OpenWithProgIds\n");
+        add_to_progids ($extension, $old_file_type);
+      }
       $regkey = {'/' => $file_type};
       do_write_regkey("Software/Classes/$extension/", $regkey, $remove_cu);
     }
@@ -1018,6 +1077,8 @@ sub update_assocs() {
 
 =head2 SHORTCUTS
 
+=over 4
+
 =item C<add_shortcut($dir, $name, $icon, $prog, $args, $batgui)>
 
 Add a shortcut, with name $name and icon $icon, pointing to
@@ -1237,25 +1298,31 @@ UNEND3
         "$uninst_dir\\uninst.bat", "", 0);
   }
   # register uninstaller
-  &log("Registering uninstaller\n");
-  my $k;
-  my $uninst_key = $Registry -> Open((admin() ? "LMachine" : "CUser") .
-      "/software/microsoft/windows/currentversion/",
-      {Access => KEY_FULL_ACCESS()});
-  if ($uninst_key) {
-    $k = $uninst_key->CreateKey(
-      "uninstall/TeXLive$::TeXLive::TLConfig::ReleaseYear/");
-    if ($k) {
-      $k->{"/DisplayName"} = "TeX Live $::TeXLive::TLConfig::ReleaseYear";
-      $k->{"/UninstallString"} = "\"$td\\tlpkg\\installer\\uninst.bat\"";
-      $k->{'/DisplayVersion'} = $::TeXLive::TLConfig::ReleaseYear;
-      $k->{'/URLInfoAbout'} = "http://www.tug.org/texlive";
+  # but not for a user install under win10 because then
+  # it shows up in Settings / Apps / Apps & features,
+  # where it will trigger an inappropriate UAC prompt
+  if (admin() || !is_ten()) {
+    &log("Registering uninstaller\n");
+    my $k;
+    my $uninst_key = $Registry -> Open((admin() ? "LMachine" : "CUser") .
+        "/software/microsoft/windows/currentversion/",
+        {Access => KEY_FULL_ACCESS()});
+    if ($uninst_key) {
+      $k = $uninst_key->CreateKey(
+        "uninstall/TeXLive$::TeXLive::TLConfig::ReleaseYear/");
+      if ($k) {
+        $k->{"/DisplayName"} = "TeX Live $::TeXLive::TLConfig::ReleaseYear";
+        $k->{"/UninstallString"} = "\"$td\\tlpkg\\installer\\uninst.bat\"";
+        $k->{'/DisplayVersion'} = $::TeXLive::TLConfig::ReleaseYear;
+        $k->{'/Publisher'} = 'TeX Live';
+        $k->{'/URLInfoAbout'} = "http://www.tug.org/texlive";
+      }
+    }
+    if (!$k and admin()) {
+      tlwarn("Failed to register uninstaller\n".
+         "You can still run $td\\tlpkg\\installer\\uninst.bat manually.\n");
+      return 0;
     }
-  }
-  if (!$k and admin()) {
-    tlwarn("Failed to register uninstaller\n".
-       "You can still run $td\\tlpkg\\installer\\uninst.bat manually.\n");
-    return 0;
   }
 }
 
