@@ -13,27 +13,35 @@ $mirrors = {
   'Asia' => {
     'China' => {
       'http://mirror.lzu.edu.cn/CTAN/' => 1,
-      'http://mirrors.opencas.cn/ctan/' => 1,
+      'http://mirrors.cqu.edu.cn/CTAN/' => 1,
+      'http://mirrors.geekpie.club/CTAN/' => 1,
+      'http://mirrors.huaweicloud.com/repository/toolkit/CTAN/' => 1,
+      'http://mirrors.shu.edu.cn/CTAN/' => 1,
+      'http://mirrors.sjtug.sjtu.edu.cn/ctan/' => 1,
       'http://mirrors.tuna.tsinghua.edu.cn/CTAN/' => 1,
       'http://mirrors.ustc.edu.cn/CTAN/' => 1
     },
+    'India' => {
+      'http://ctan.imsc.res.in/' => 1,
+      'http://mirror.iopb.res.in/tex-archive/' => 1
+    },
     'Iran' => {
       'http://ctan.asis.io/' => 1,
       'http://ctan.um.ac.ir/' => 1,
-      'http://ctan.yazd.ac.ir/' => 1
+      'http://ctan.yazd.ac.ir/' => 1,
+      'http://repo.iut.ac.ir/tex-archive/' => 1
     },
     'Japan' => {
       'ftp://ftp.kddilabs.jp/CTAN/' => 1,
-      'ftp://ftp.u-aizu.ac.jp/pub/tex/CTAN/' => 1,
-      'http://ftp.jaist.ac.jp/pub/CTAN/' => 1
+      'http://ftp.jaist.ac.jp/pub/CTAN/' => 1,
+      'http://ftp.yz.yamagata-u.ac.jp/pub/CTAN/' => 1
     },
     'Korea' => {
+      'http://ftp.harukasan.org/CTAN/' => 1,
       'http://ftp.kaist.ac.kr/pub/tex-archive/' => 1,
       'http://ftp.ktug.org/tex-archive/' => 1,
-      'http://ftp.neowiz.com/CTAN/' => 1
-    },
-    'Malaysia' => {
-      'http://wbc.upm.edu.my/tex-archive/' => 1
+      'http://ftp.neowiz.com/CTAN/' => 1,
+      'http://mirror.navercorp.com/CTAN/' => 1
     },
     'Philippines' => {
       'http://mirror.pregi.net/tex-archive/' => 1
@@ -41,11 +49,15 @@ $mirrors = {
     'Taiwan' => {
       'ftp://ftp.ccu.edu.tw/pub/tex/' => 1,
       'http://ftp.yzu.edu.tw/CTAN/' => 1
+    },
+    'Thailand' => {
+      'http://mirror.kku.ac.th/CTAN/' => 1
     }
   },
   'Europe' => {
     'Austria' => {
-      'http://mirror.easyname.at/ctan/' => 1
+      'http://mirror.easyname.at/ctan/' => 1,
+      'http://mirror.reismil.ch/CTAN/' => 1
     },
     'Belarus' => {
       'http://mirror.datacenter.by/pub/mirrors/CTAN/' => 1
@@ -60,7 +72,9 @@ $mirrors = {
       'ftp://ftp.funet.fi/pub/TeX/CTAN/' => 1
     },
     'France' => {
+      'http://ctan.crest.fr/tex-archive/' => 1,
       'http://ctan.mines-albi.fr/' => 1,
+      'http://ctan.tetaneutral.net/' => 1,
       'http://distrib-coffee.ipsl.jussieu.fr/pub/mirrors/ctan/' => 1,
       'http://mirror.ibcp.fr/pub/CTAN/' => 1,
       'http://mirrors.ircam.fr/pub/CTAN/' => 1,
@@ -70,10 +84,12 @@ $mirrors = {
       'ftp://ftp.fu-berlin.de/tex/CTAN/' => 1,
       'ftp://ftp.rrzn.uni-hannover.de/pub/mirror/tex-archive/' => 1,
       'ftp://ftp.tu-chemnitz.de/pub/tex/' => 1,
+      'http://ctan.mirror.norbert-ruehl.de/' => 1,
       'http://ctan.space-pro.be/tex-archive/' => 1,
       'http://ftp.fau.de/ctan/' => 1,
-      'http://vesta.informatik.rwth-aachen.de/ftp/pub/mirror/ctan/' => 1,
-      'http://www.bothelp.net/mirrors/ctan/' => 1
+      'http://mirror.informatik.hs-fulda.de/tex-archive/' => 1,
+      'http://packages.oth-regensburg.de/ctan/' => 1,
+      'http://vesta.informatik.rwth-aachen.de/ftp/pub/mirror/ctan/' => 1
     },
     'Greece' => {
       'http://ftp.cc.uoc.gr/mirrors/CTAN/' => 1
@@ -83,7 +99,9 @@ $mirrors = {
     },
     'Netherlands' => {
       'http://ctan.cs.uu.nl/' => 1,
-      'http://ftp.snt.utwente.nl/pub/software/tex/' => 1
+      'http://ctan.triasinformatica.nl/' => 1,
+      'http://ftp.snt.utwente.nl/pub/software/tex/' => 1,
+      'http://mirror.koddos.net/CTAN/' => 1
     },
     'Norway' => {
       'http://ctan.uib.no/' => 1
@@ -95,8 +113,10 @@ $mirrors = {
     },
     'Portugal' => {
       'ftp://ftp.di.uminho.pt/pub/ctan/' => 1,
-      'ftp://ftp.ist.utl.pt/pub/ctan/' => 1,
-      'http://mirrors.fe.up.pt/pub/CTAN/' => 1
+      'http://mirrors.up.pt/pub/CTAN/' => 1
+    },
+    'Romania' => {
+      'http://mirrors.nxthost.com/ctan/' => 1
     },
     'Russia' => {
       'http://ctan.altspu.ru/' => 1,
@@ -124,9 +144,6 @@ $mirrors = {
     }
   },
   'North America' => {
-    'Australia' => {
-      'http://mirror.aarnet.edu.au/pub/CTAN/' => 1
-    },
     'Canada' => {
       'http://ctan.forsale.plus/' => 1,
       'http://ctan.math.ca/tex-archive/' => 1,
@@ -138,26 +155,29 @@ $mirrors = {
     'Costa Rica' => {
       'http://mirrors.ucr.ac.cr/CTAN/' => 1
     },
-    'New Zealand' => {
-      'http://mirror.aut.ac.nz/CTAN/' => 1
-    },
     'USA' => {
-      'http://ctan.mackichan.com/' => 1,
+      'http://ctan.math.illinois.edu/' => 1,
+      'http://ctan.math.washington.edu/tex-archive/' => 1,
       'http://ctan.mirrors.hoobly.com/' => 1,
-      'http://ctan.sharelatex.com/tex-archive/' => 1,
       'http://mirror.hmc.edu/ctan/' => 1,
-      'http://mirror.jmu.edu/pub/CTAN/' => 1,
-      'http://mirror.unl.edu/ctan/' => 1,
+      'http://mirror.las.iastate.edu/tex-archive/' => 1,
       'http://mirror.utexas.edu/ctan/' => 1,
       'http://mirrors.concertpass.com/tex-archive/' => 1,
       'http://mirrors.ibiblio.org/pub/mirrors/CTAN/' => 1,
       'http://mirrors.rit.edu/CTAN/' => 1
     }
   },
+  'Oceania' => {
+    'Australia' => {
+      'http://mirror.aarnet.edu.au/pub/CTAN/' => 1
+    },
+    'New Zealand' => {
+      'http://mirror.aut.ac.nz/CTAN/' => 1
+    }
+  },
   'South America' => {
     'Brazil' => {
-      'http://linorg.usp.br/CTAN/' => 1,
-      'http://repositorios.cpai.unb.br/ctan/' => 1
+      'http://linorg.usp.br/CTAN/' => 1
     },
     'Chile' => {
       'http://ftp.inf.utfsm.cl/pub/tex-archive/' => 1
