@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: install-menu-wizard.pl 41176 2016-05-16 00:42:28Z preining $
+# $Id: install-menu-wizard.pl 47481 2018-04-29 14:52:02Z siepo $
 # Copyright 2009-2016 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
@@ -14,18 +14,19 @@ $::menurevision = $1;
 require("TeXLive/trans.pl");
 load_translations();
 
+require("$::installerdir/tlpkg/installer/texdirsel.pl");
 
 #
 # the following lists define which options are shown in the Option screen
 # for unix and windows. On W32 with admin privileges both @w32 list options
 # are shown
 # the values are keys into the %vars array
-my @unix_opts = qw/option_letter/;
-my @w32_opts = qw/option_letter 
-                  option_desktop_integration 
+my @unix_opts = qw/instopt_letter/;
+my @w32_opts = qw/instopt_letter 
+                  tlpdbopt_desktop_integration 
                   collection-texworks
                  /;
-my @w32_admin_opts = qw/option_w32_multi_user/;
+my @w32_admin_opts = qw/tlpdbopt_w32_multi_user/;
 
 my @opts_list = ();
 if (win32()) {
@@ -37,15 +38,15 @@ if (win32()) {
   push @opts_list, @unix_opts;
 }
 my %opts_to_str = (
-  "option_letter"              => __("Default paper size"),
-  "option_desktop_integration" => __("Add menu shortcuts"),
-  "option_file_assocs"         => __("Change file associations"),
-  "option_path"                => __("Adjust PATH setting in registry"),
-  "option_w32_multi_user"      => __("Installation for all users"),
-  "collection-texworks"        => __("Install TeXworks front end"),
+  "instopt_letter"               => __("Default paper size"),
+  "tlpdbopt_desktop_integration" => __("Add menu shortcuts"),
+  "tlpdbopt_file_assocs"         => __("Change file associations"),
+  "instopt_adjustpath"           => __("Adjust PATH setting in registry"),
+  "tlpdbopt_w32_multi_user"      => __("Installation for all users"),
+  "collection-texworks"          => __("Install TeXworks front end"),
 );
 my %opts_choices = (
-  "option_letter" => ["A4", "letter"],
+  "instopt_letter" => ["A4", "letter"],
 );
 
 
@@ -68,8 +69,8 @@ require Tk::BrowseEntry;
 require Tk::Dialog;
 require Tk::DialogBox;
 require Tk::PNG;
-require Tk::ROText;
-require Tk::ProgressBar;
+#require Tk::ROText;
+#require Tk::ProgressBar;
 require Tk::Font;
 
 use utf8;
@@ -82,10 +83,9 @@ my $can;
 my $prv;
 my $nxt;
 my $img;
-my $dest;
 my $dest_display;
 my $warning;
-my $mw;
+our $mw;
 my $usedfont;
 my $fmain;
 my $fbuttons;
@@ -119,44 +119,12 @@ sub menu_abort {
     $mw->destroy;
 }
 
-sub setup_hooks_wizard {
-  @::info_hook = ();
-  push @::info_hook,
-    sub {
-      return unless defined($mw);
-      wizard_update_status(join(" ",@_));
-      $mw->update;
-    };
-  push @::warn_hook,
-    sub {
-      return unless defined($mw);
-      wizard_update_status(join(" ",@_));
-      $mw->update;
-    };
-  @::install_packages_hook = ();
-  push @::install_packages_hook, \&wizard_update_progressbar;
-  push @::install_packages_hook, sub { $mw->update; };
-}
-
-sub wizard_update_status {
-  my ($p) = @_;
-  return unless defined($::progressw);
-  $::progressw->insert("end", "$p");
-  $::progressw->see("end");
-}
-sub wizard_update_progressbar {
-  my ($n,$total) = @_;
-  if (defined($n) && defined($total)) {
-    $::progress->value(int($n*100/$total));
-  }
-}
-
 ################# WELCOME SCREEN ######################################
 
 sub run_menu_wizard {
   $mw = Tk::MainWindow->new(-width => $MWIDTH, -height => $MHEIGHT);
   $mw->protocol('WM_DELETE_WINDOW' => \&menu_abort);
-  setup_hooks_wizard();
+  #setup_hooks_wizard();
 
   my $img = $mw->Photo(-format => 'png', -file => "$::installerdir/tlpkg/installer/texlive.png");
   $mw->Label(-image => $img, -background => "#0078b8")->place(-x => 0, -y => 0);
@@ -172,7 +140,7 @@ sub run_menu_wizard {
 
   $tit->place(-x => 0, -y => 0);
 
-  $counter = $ftitle->Label(-text => "1/5");
+  $counter = $ftitle->Label(-text => "1/4");
   $counter->place(-x => $INNERWIDTH, -y => 0, -anchor => "ne");
 
   $fmain = $mw->Frame(-height => $INNERHEIGHT, -width => $INNERWIDTH);
@@ -201,12 +169,12 @@ sub reset_start {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "1/5");
+  $counter->configure(-text => "1/4");
   $prv->placeForget;
 
   my $inf = $fmain->Label(
     -text => __("Welcome to the installation of TeX Live %s\nhttp://tug.org/texlive\n\nThis wizard will guide you through the installation.", $TeXLive::TLConfig::ReleaseYear)
-      . ( (win32()) ? "\n\n" . __("Best to disable your virus scanner during installation.") : "" )
+      . ( (win32()) ? "\n\n" . __("In case of trouble, try to disable your virus scanner during installation.") : "" )
        . "\n\n"
        . __("For an advanced, customizable installation, please consult\nthe web pages or installation guide.")
       . "\n"
@@ -246,7 +214,7 @@ sub ask_mirror {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "1-1/5");
+  $counter->configure(-text => "1-1/4");
 
   my @mirror_list;
   my @netlst;
@@ -314,7 +282,7 @@ sub ask_mirror_hierarchical {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "1-1/5");
+  $counter->configure(-text => "1-1/4");
 
   our $mirrors;
   require("installer/mirrors.pl");
@@ -405,7 +373,7 @@ sub load_remote_screen {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "1-2/5");
+  $counter->configure(-text => "1-2/4");
 
   if ($::init_remote_needed) {
     my $labela = $fmain->Label(-text => __('Please wait while the repository database is loaded.'))->place(-x => 0, -y => 50);
@@ -448,10 +416,9 @@ sub ask_path {
     $_->destroy;
   }
 
-  $counter->configure(-text => "2/5");
+  $counter->configure(-text => "2/4");
 
-  $dest = $vars{'TEXDIR'};
-  $dest_display = native_slashify($dest);
+  $dest_display = native_slashify($vars{'TEXDIR'});
 
   my $lab = $fmain->Label(-text => __('Destination folder:'));
   my $val = $fmain->Label(-textvar => \$dest_display);
@@ -523,27 +490,6 @@ sub check_show_warning {
     $nxt->configure(-state => "disabled");
   }
 }
-  
-sub change_path {
-  my $val = $dest;
-  my $sw = $mw->Toplevel(-title => "Changing TEXDIR");
-  $sw->transient($mw);
-  $sw->grab();
-  $sw->Label(-text => __('Enter path for') . " TEXDIR: ")->pack(-padx => "2m", -pady => "2m");
-  my $entry = $sw->Entry(-text => native_slashify($val), -width => 60);
-  $entry->pack(-padx => "2m", -pady => "2m")->focus();
-  my $f = $sw->Frame;
-  my $okbutton = $f->Button(-text => __('Ok'), -width => 10, 
-     -relief => "ridge",
-     -command => sub { $val = forward_slashify($entry->get); callback_change_texdir($val) ; $sw->destroy })->pack(-side => 'left', -padx => "2m", -pady => "2m");
-  my $cancelbutton = $f->Button(-text => __('Cancel'), -relief => "ridge",
-     -width => 10,
-     -command => sub { $sw->destroy })->pack(-side => 'right', -padx => "2m", -pady => "2m");
-  $f->pack(-expand => 'x');
-  # bindings
-  $sw->bind('<Return>' => [ $okbutton, 'Invoke']);
-  $sw->bind('<Escape>' => [ $cancelbutton, 'Invoke']);
-}
 
 sub callback_change_texdir {
   my ($val) = @_;
@@ -572,8 +518,8 @@ sub callback_change_texdir {
     $vars{'TEXMFSYSVAR'}="$texdirnoslash/texmf-var";
     $vars{'TEXMFSYSCONFIG'}="$texdirnoslash/texmf-config";
   }
-  $dest = $vars{'TEXDIR'};
-  $dest_display = native_slashify($dest); # useful as -textvar value in Labels
+  #$dest = $vars{'TEXDIR'};
+  $dest_display = native_slashify($vars{'TEXDIR'}); # useful as -textvar value in Labels
   check_show_warning();
 }
 
@@ -583,7 +529,7 @@ sub ask_options {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "3/5");
+  $counter->configure(-text => "3/4");
 
   my $inf = $fmain->Label(-text => __("This screen allows you to configure some options"), -justify => "left");
   $inf->place(-x => 0, -y => 20);
@@ -629,7 +575,7 @@ sub ask_go {
   for ($fmain->children) {
     $_->destroy;
   }
-  $counter->configure(-text => "4/5");
+  $counter->configure(-text => "4/4");
   my $inf = $fmain->Label(-justify => "left", -text => __("We are ready to install TeX Live %s.\nThe following settings will be used.\nIf you want to change something please go back,\notherwise press the \"Install\" button.", $TeXLive::TLConfig::ReleaseYear));
 
 
@@ -656,85 +602,12 @@ sub ask_go {
 
   
   $nxt->configure(-text => __('Install'), 
-                  -command => \&wizard_installation_window);
+                  -command => sub { $return = $MENU_INSTALL; $mw->destroy; });
+#                  -command => \&wizard_installation_window);
   $prv->configure(-text => __('< Back'), -command => \&ask_options);
   $can->place(-x => $LEFT, -y => ($MHEIGHT - $BOTTOM), -anchor => "sw");
 }
 
-sub wizard_installation_window {
-  for ($fmain->children) {
-    $_->destroy;
-  }
-  $counter->configure(-text => "5/5");
-  # create a progress bar window
-  # compute the height of the Text by the given font
-
-  $::progressw = $fmain->Scrolled("ROText", -scrollbars => "e",
-                                -wrap => "word");
-
-  # we want to have the progressbar about 20px wide, so compute how
-  # many lines of the current font do fit into the remaining area
-  my $lines = int( ($INNERHEIGHT - 20) / $lineskip);
-  # it seems that on Windows the computation is not right, the
-  # progress bar overwrites the last line of the text widget
-  # remove one line here
-  $lines-- if win32();
-  $::progressw->configure(-height => $lines);
-  $::progressw->place(-x => 0, -y => 0, -width => $INNERWIDTH); 
-
-  # that is necessary otherwise the progressbar gets very strange dimensions
-  $fmain->update;
-
-
-  my $percent_done = 0;
-
-  # compute the remaining space in pixel for the progressbar
-  my $pw = $INNERHEIGHT - ($lines * $lineskip) - 5;
-  # make sure that the line we remove above for Windows is not re-added
-  # to the size of the progressbar. The 7 was found by trial and error
-  $pw -= ($lineskip + 7) if win32();
-  $::progress = $fmain->ProgressBar(-variable => \$percent_done,
-      -width => $pw, -length => $INNERWIDTH,
-      -from => 0, -to => 110, -blocks => 10,
-      -colors => [ 0, '#0078b8' ]);
-  $::progress->place(-x => 0, -y => $INNERHEIGHT, -anchor => "sw");
-
-  #
-  # change the buttons so that the Prev disappears, the Next becomes
-  # Cancel, and the Cancel button disappears
-  $prv->placeForget;
-  $nxt->placeForget;
-  #$can->configure(-text => __('Cancel'),
-  #                -command => sub { $return = $MENU_ABORT; $mw->destroy; });
-  calc_depends();
-  do_installation();
-  $::progress->value(110);
-  $return = $MENU_ALREADYDONE;
-  my $t = __("See %s/index.html for links to documentation.\nThe TeX Live web site (http://tug.org/texlive/) contains any updates and corrections. TeX Live is a joint project of the TeX user groups around the world; please consider supporting it by joining the group best for you. The list of groups is available on the web at http://tug.org/usergroups.html.", $::vars{'TEXDIR'});
-  if (!win32()) {
-    $t .= "\n\n" . __("Add %s/texmf-dist/doc/man to MANPATH.\nAdd %s/texmf-dist/doc/info to INFOPATH.\nMost importantly, add %s/bin/%s\nto your PATH for current and future sessions.", $::vars{'TEXDIR'}, $::vars{'TEXDIR'}, $::vars{'TEXDIR'}, $::vars{'this_platform'});
-  }
-  if (@::WARNLINES) {
-    $t .= "\n\n" . __("There were some warnings during the installation process.\nHere is the list of warning messages:") . "\n";
-    $t .= join('', @::WARNLINES);
-    $t =~ s/\n\z//;
-  }
-  $t .= "\n\n" . __('Welcome to TeX Live!');
-  #$t =~ s/\\n/\n/g;
-  my $linechar = $::progressw->index("end");
-  $::progressw->markSet("finaltext", $linechar);
-  $::progressw->markGravity("finaltext", "left");
-  $::progressw->insert("end", "\n$t");
-  $::progressw->see("end");
-  $::progressw->tagAdd("centered", $linechar, "end");
-  $::progressw->tagConfigure("centered", -justify => "center");
-  my $rb = $MWIDTH - $RIGHT;
-  $nxt->configure(-text => __('Finish'),
-                -command => sub { $mw->destroy; });
-  $nxt->place(-x => ($MWIDTH - $RIGHT) ,
-              -y => ($MHEIGHT - $BOTTOM), -anchor => "se")->focus();
-}
-
 ################### END OF MODULE RETURN 1 FOR REQUIRE ###########
 
 1;
